@@ -1,6 +1,6 @@
 package YATG::Store::NSCA;
 {
-  $YATG::Store::NSCA::VERSION = '5.130600';
+  $YATG::Store::NSCA::VERSION = '5.130840';
 }
 
 use strict;
@@ -40,6 +40,7 @@ sub store {
     my $cache = YATG::SharedStorage->cache();
     my $nsca_server = $config->{nsca}->{nsca_server}
         or die "Must specify an nsca server in configuration.\n";
+    my $nsca_port = $config->{nsca}->{nsca_port};
 
     # results look like this:
     #   $results->{device}->{leaf}->{port} = {value}
@@ -65,7 +66,9 @@ sub store {
     }
 
     # open connection to send_nsca
-    open(my $send_nsca, '|-', $send_nsca_cmd, '-H', $nsca_server, '-c', $send_nsca_cfg, '-d', '!', '-to', 1)
+    open(my $send_nsca, '|-', $send_nsca_cmd,
+                              '-H', $nsca_server, '-p', $nsca_port,
+                              '-c', $send_nsca_cfg, '-d', '!', '-to', 1)
         or die "can't fork send_nsca: $!";
 
     # build and send report for each host
@@ -228,8 +231,8 @@ sub store {
 
 # ABSTRACT: Back-end module to send polled data to a Nagios service
 
-__END__
 
+__END__
 =pod
 
 =head1 NAME
@@ -238,7 +241,7 @@ YATG::Store::NSCA - Back-end module to send polled data to a Nagios service
 
 =head1 VERSION
 
-version 5.130600
+version 5.130840
 
 =head1 DESCRIPTION
 
@@ -281,6 +284,7 @@ override builtin defaults, like so:
      dbi_host_query: 'SELECT ip, host AS name from hosts'
      dbi_interfaces_query: 'SELECT name FROM hostinterfaces WHERE ip = ?'
  nsca:
+     nsca_port: '5667'
      send_nsca_cmd: '/usr/bin/send_nsca'
      config_file:   '/etc/send_nsca.cfg'
      ignore_ports:  '^(?:Vlan|Po)\d+$'
@@ -321,6 +325,11 @@ The location of the C<send_nsca> command on your system. YATG will default to
 C</usr/bin/send_nsca> and if you supply a value it must be a fully qualified
 path.
 
+=item C<nsca_port>
+
+The port where the NSCA daemon is listening, and the C<send_nsca> command
+should connect and submit results.
+
 =item C<config_file>
 
 The location of the configuration file for the C<send_nsca> program. This
@@ -373,3 +382,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
